Creating plug-ins 
==================

As seen on the :doc:`/plugins` page, metasyn can be extended by plug-ins. This page describes how to create your own plug-ins.

.. _privacy_plugin:

Creating a privacy plug-in
--------------------------
In case you want to create a new distribution as part of an add-on, you can easily do so by following the available `privacy plug-in template <https://github.com/sodascience/metasyn-privacy-template>`_.

.. _dist_plugin:

Creating a distribution plug-in
-------------------------------
In case you want to create a new distribution as part of an add-on, as opposed to it being implemented in the core package, you can easily do so by following the available `distribution plug-in template <https://github.com/sodascience/metasyn-distribution-template>`_.